from globals.api.src.service import GlobalsManager
from globals.api.src.service.GlobalsManager import (
    Globals,
    importResource,
    importModule,
    newGlobalsInstance,
    getGlobalsInstance,
    globalsInstanceIsNone,
    updateGlobalsInstance,
    hardUpdateGlobalsInstance,
    eraseGlobalsInstance,
    runBeforeTest,
    runAfterTest,
    AttributeKey
)
